package tech.mercantec.easyeat.ui.dishes

import android.app.Activity
import android.app.ProgressDialog
import android.os.Bundle
import android.view.LayoutInflater
import android.widget.ArrayAdapter
import android.widget.Button
import android.widget.EditText
import android.widget.ImageButton
import android.widget.LinearLayout
import android.widget.Spinner
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.createRecipe
import tech.mercantec.easyeat.models.Ingredient
import tech.mercantec.easyeat.models.Recipe
import kotlin.concurrent.thread

class CreateDishActivity : AppCompatActivity() {

    private lateinit var ingredientContainer: LinearLayout

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_create_dish_form)

        ingredientContainer = findViewById(R.id.ingredientContainer)
        val addButton: Button = findViewById(R.id.addIngredientButton)

        // Add the first ingredient row manually at startup
        addIngredientRow()

        // Set up button to add new rows
        addButton.setOnClickListener {
            addIngredientRow()
        }

        val saveButton: Button = findViewById(R.id.saveDishButton)
        saveButton.setOnClickListener {
            val ingredientList = collectIngredients()
            val instructions = findViewById<EditText>(R.id.instructions).text.toString().trim()
            val directions: List<String> = instructions
                .split("\n")
                .map { line -> line.trim() }
                .filter { it.isNotEmpty() }

            val recipe = Recipe(
                name = findViewById<EditText>(R.id.dishName).text.toString().trim(),
                description = findViewById<EditText>(R.id.dishDescription).text.toString().trim(),
                directions = directions,
                ingredients = ingredientList
            )

            val progressDialog = ProgressDialog(this)
            progressDialog.setMessage("Loading...")
            progressDialog.show()
            thread {
                try {
                    createRecipe(this, recipe)
                } catch (e: ApiRequestException) {
                    runOnUiThread {
                        Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                    }

                    return@thread
                } finally {
                    runOnUiThread {
                        progressDialog.hide()
                    }
                }

                runOnUiThread {
                    Toast.makeText(this, "Password changed successfully", Toast.LENGTH_LONG).show()
                }

                setResult(Activity.RESULT_OK)
                finish()
            }
        }
    }

    private fun addIngredientRow() {
        val inflater = LayoutInflater.from(this)
        val ingredientRow = inflater.inflate(R.layout.activity_create_dish_ingredient_row, null)
        val spinnerMeasurements = ingredientRow.findViewById<Spinner>(R.id.measurementsDropDown)
        spinnerMeasurements.adapter = ArrayAdapter(
            this,
            android.R.layout.simple_spinner_item,
            listOf("g", "kg", "ml", "l", "tsp", "tbsp", "cup", "pcs", "pinch", "dash")
        )

        // Handle remove button in each row
        val removeButton: ImageButton = ingredientRow.findViewById(R.id.removeButton)
        removeButton.setOnClickListener {
            ingredientContainer.removeView(ingredientRow)
        }

        ingredientContainer.addView(ingredientRow)
    }

    private fun collectIngredients(): List<Ingredient> {
        val ingredients = mutableListOf<Ingredient>()

        for (i in 0 until ingredientContainer.childCount) {
            val ingredientView = ingredientContainer.getChildAt(i)

            // Find views inside this ingredient row

            val ingredientEditText = ingredientView.findViewById<EditText>(R.id.ingredientNameEditText)
            val amountEditText = ingredientView.findViewById<EditText>(R.id.ingredientAmountEditText)
            val spinner = ingredientView.findViewById<Spinner>(R.id.measurementsDropDown)

            val element = ingredientEditText.text.toString().trim()
            val amount = amountEditText.text.toString().trim()
            val unit = spinner.selectedItem.toString()

            // Optional: Only add non-empty rows
            if (element.isNotEmpty() && amount.isNotEmpty()) {
                ingredients.add(Ingredient(name = element, amount = amount.toDouble(), unit = unit))
            }
        }

        return ingredients
    }

}
