package tech.mercantec.easyeat.ui.dishes

import android.app.Activity
import android.app.ProgressDialog
import android.os.Bundle
import android.text.Html
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.LinearLayout
import android.widget.Toast
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.RecipeDetailsResponse
import tech.mercantec.easyeat.helpers.getRecipeDetails
import kotlin.concurrent.thread
import android.widget.EditText
import android.widget.ImageButton
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.core.widget.doAfterTextChanged
import tech.mercantec.easyeat.helpers.AddRecipeToShoppingList
import tech.mercantec.easyeat.models.Ingredient

class DishDetailsActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_dish_details)

        val ingredientsContainer = findViewById<LinearLayout>(R.id.ingredients)
        val multiplierEditText = findViewById<EditText>(R.id.ingredient_multiplier)

        val dishId = intent.getIntExtra("dish_id", -1)
        if (dishId == -1) {
            Toast.makeText(this, "No dish ID provided", Toast.LENGTH_SHORT).show()
            finish()
            return
        }

        thread {
            val recipe: RecipeDetailsResponse
            try {
                recipe = getRecipeDetails(this, dishId)
            } catch (e: ApiRequestException) {
                runOnUiThread {
                    Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                }
                return@thread
            }
            Log.i("DISH", recipe.ingredients.toString())
            val instructionsLayout = findViewById<LinearLayout>(R.id.instructions)

// Example data: recipe.ingredients and recipe.directions
            runOnUiThread {
                findViewById<TextView>(R.id.dishDetailName).text = recipe.name
                findViewById<TextView>(R.id.dishDetailDescription).text = recipe.description

                // Populate Instructions (if directions are strings)
                recipe.directions.forEachIndexed { index, direction ->
                    val textView = TextView(this).apply {
                        text = "${index + 1}. $direction"
                        textSize = 18f
                        setPadding(0, 8, 0, 8)
                    }
                    instructionsLayout.addView(textView)
                }
            }

            fun displayIngredients(ingredients: List<Ingredient>, multiplier: Int, container: LinearLayout) {
                container.removeAllViews() // clear previous views

                for (ingredient in ingredients) {
                    val row = TextView(this)
                    val amount = (ingredient.amount ?: 0.0) * multiplier
                    val amountStr = amount.toBigDecimal().stripTrailingZeros().toPlainString()

                    row.text = Html.fromHtml("&#8226; ${ingredient.name}: $amountStr ${ingredient.unit ?: ""}", Html.FROM_HTML_MODE_LEGACY)
                    row.textSize = 18f
                    row.setPadding(0, 8, 0, 8)
                    container.addView(row)
                }
            }

            runOnUiThread {
                val nameView = findViewById<TextView>(R.id.dishDetailName)
                val descView = findViewById<TextView>(R.id.dishDetailDescription)

                nameView.text = recipe.name
                descView.text = recipe.description

                // Default multiplier
                var multiplier = 1

                // Initial display
                displayIngredients(recipe.ingredients, multiplier, ingredientsContainer)

                // Listen for user input changes
                multiplierEditText.doAfterTextChanged {
                    multiplier = it.toString().toIntOrNull() ?: 1
                    displayIngredients(recipe.ingredients, multiplier, ingredientsContainer)
                }

                findViewById<ImageButton>(R.id.increment_multiplier).setOnClickListener {
                    multiplier++
                    multiplierEditText.setText(multiplier.toString(), TextView.BufferType.EDITABLE)

                    displayIngredients(recipe.ingredients, multiplier, ingredientsContainer)
                }

                findViewById<ImageButton>(R.id.decrement_multiplier).setOnClickListener {
                    if (multiplier <= 1) return@setOnClickListener

                    multiplier--
                    multiplierEditText.setText(multiplier.toString(), TextView.BufferType.EDITABLE)

                    displayIngredients(recipe.ingredients, multiplier, ingredientsContainer)
                }

                // You can do the same for directions if needed
            }

            val saveButton: Button = findViewById(R.id.addDishToShoppingList)
            saveButton.setOnClickListener {
                val progressDialog = ProgressDialog(this)
                progressDialog.setMessage("Loading...")
                progressDialog.show()
                thread {
                    try {
                        val multiplierEditText = findViewById<EditText>(R.id.ingredient_multiplier)
                        val multiplierText = multiplierEditText.text.toString()
                        AddRecipeToShoppingList(this, dishId, multiplierText)
                    } catch (e: ApiRequestException) {
                        runOnUiThread {
                            Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                        }

                        return@thread
                    } finally {
                        runOnUiThread {
                            progressDialog.hide()
                        }
                    }

                    runOnUiThread {
                        Toast.makeText(this, "Password changed successfully", Toast.LENGTH_LONG).show()
                    }

                    setResult(Activity.RESULT_OK)
                    finish()
                }
            }

        }
    }
}