package tech.mercantec.easyeat.ui.dishes

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.PopupMenu
import android.widget.Toast
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.fragment.app.Fragment
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.databinding.FragmentDishesBinding
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.GetAllRecipesResponse
import tech.mercantec.easyeat.helpers.getAllRecipes
import tech.mercantec.easyeat.models.DishListItem
import tech.mercantec.easyeat.models.Recipe
import kotlin.concurrent.thread

class DishesFragment : Fragment() {

    private var _binding: FragmentDishesBinding? = null
    private lateinit var createDishLauncher: ActivityResultLauncher<Intent>
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentDishesBinding.inflate(inflater, container, false)
        val root: View = binding.root

        loadRecipes()

        binding.addDish.setOnClickListener {
            val popup = PopupMenu(requireActivity(), it)

            popup.apply {
                menuInflater.inflate(R.menu.create_dish_menu, menu)

                setOnMenuItemClickListener {
                    when (it.itemId) {
                        R.id.create_manually -> {
                            val intent = Intent(requireContext(), CreateDishActivity::class.java)
                            createDishLauncher.launch(intent)

                            true
                        }
                        R.id.create_with_ai -> {
                            val intent = Intent(requireContext(), GenerateRecipeActivity::class.java)
                            createDishLauncher.launch(intent)

                            true
                        }
                        else -> false
                    }
                }

                show()
            }
        }


        return root

    }
    fun DishesFragment.loadRecipes() {
        thread {
            val recipes: List<GetAllRecipesResponse>
            try {
                recipes = getAllRecipes(requireContext())
            } catch (e: ApiRequestException) {
                activity?.runOnUiThread {
                    Toast.makeText(requireContext(), e.message, Toast.LENGTH_LONG).show()
                }
                return@thread
            }

            val dishes = recipes.map {
                DishListItem(it.id, it.name, it.description)
            }

            activity?.runOnUiThread {
                val adapter = DishAdapter(requireContext(), dishes) { selectedDish ->
                    // Open details activity
                    val intent = Intent(requireContext(), DishDetailsActivity::class.java)
                    intent.putExtra("dish_id", selectedDish.id)
                    startActivity(intent)
                }
                binding.dishesList.adapter = adapter
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        createDishLauncher = registerForActivityResult(ActivityResultContracts.StartActivityForResult()) { result ->
            if (result.resultCode == Activity.RESULT_OK) {
                loadRecipes()
            }
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}
