package tech.mercantec.easyeat.ui.dishes

import android.app.ProgressDialog
import android.os.Bundle
import android.widget.Button
import android.widget.EditText
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.createRecipe
import tech.mercantec.easyeat.helpers.generateRecipeWithAI
import tech.mercantec.easyeat.models.Recipe
import java.util.Locale
import kotlin.concurrent.thread

class GenerateRecipeActivity : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_generate_recipe)

        findViewById<Button>(R.id.generate).setOnClickListener {
            val name = findViewById<EditText>(R.id.dish_title).text.toString()

            val progressDialog = ProgressDialog(this)
            progressDialog.setMessage("Generating...")
            progressDialog.show()

            thread {
//                val response: GenerateRecipeResponse
                try {
                    val recipe = generateRecipeWithAI(this, name, Locale.getDefault().displayLanguage)

                    runOnUiThread {
                        progressDialog.setMessage("Saving...")
                    }

                    createRecipe(this, recipe)

                    finish()
                } catch (e: ApiRequestException) {
                    runOnUiThread {
                        Toast.makeText(this, e.message, Toast.LENGTH_LONG).show()
                    }
                } finally {
                    runOnUiThread {
                        progressDialog.hide()
                    }
                }
            }
        }
    }
}
